@@ -23,17 +23,12 @@ import socket
 import hashlib
 import textwrap
 
-# Debugging modules
-import traceback
 import logging
 
 # Third party modules
 import requests
 from markdown2 import markdown as _markdown
 
-# Get version info
-from .__version__ import __version__
-
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.StreamHandler())
 
@@ -59,13 +54,13 @@ def u(text):
 
 def quote(url):
     if PY3:
-        return _quote(bytes(str(url), encoding="utf-8"))
-    return _quote(str(url))
+        return _quote(bytes(u(url), encoding="utf-8"))
+    return _quote(u(url))
 
 
 def unquote(url):
     if PY3:
-        return _unquote(str(url), encoding="utf-8")
+        return _unquote(u(url), encoding="utf-8")
     return _unquote(u(url)).decode("utf-8")
 
 
@@ -160,10 +155,11 @@ def dotget(obj, expr, optional=False):
     context = obj
     for token in expr.split("."):
         try:
-            context = context.get(token)
-        except AttributeError:
+            context = context[token]
+        except KeyError:
             if optional:
                 return None
+            raise
     return context
 
 
@@ -267,7 +263,7 @@ class Tispoon(TispoonBase):
             app_secret = os.getenv("TISPOON_APP_SECRET")
 
         if not app_id or not app_secret:
-            raise ValueError("app_id, app_secret 둘 중 하나는 반드시 제공되어야 합니다.")
+            raise ValueError("app_id, app_secret 값이 제공되어야 합니다.")
 
         # 보안을 위한 임의 토큰을 생성합니다.
         state = hashlib.sha256(os.urandom(32)).hexdigest()
@@ -294,7 +290,7 @@ class Tispoon(TispoonBase):
         try:
             browser = webbrowser.get()
             browser.open(url, new=2)
-        except webbrowser.Error:  # 웹 브라우저가 존재하지 않는경우 인증 주소를 stdout으로 알립니다.
+        except webbrowser.Error:  # 웹 브라우저가 존재하지 않는경우 인증 주소를 stderr으로 알립니다.
             print("다음의 주소를 방문하여 권한을 허락해주세요.", file=sys.stderr)
             print(url, file=sys.stderr)
 
@@ -402,7 +398,7 @@ class Tispoon(TispoonBase):
         Args:
             path (str): 문자열로 이루어진 URL 경로입니다.
             output (str): 응답형식을 지정하며 생략가능합니다.
-                생략할 경우 요청헤더의 `Content-Type`을 보고 응답형식을 결정하며 기본 값은 `xml`입니다.
+                생략할 경우 요청헤더의 `Content-Type`을 보고 응답형식을 결정하며 기본 값은 `json`입니다.
             kwargs (dict): URL parameter로 변환 될 객체입니다.
                 `key=value, key2=value2` 형태의 인자가 `?key=value&key2=value2`처럼 변환됩니다.
 
@@ -434,10 +430,10 @@ class Tispoon(TispoonBase):
             r = requests.get(url)
 
         try:
-            res = json.loads(r.text, encoding="utf-8")
+            res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -472,7 +468,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -533,6 +529,9 @@ class Tispoon(TispoonBase):
                 def remove_prefix(url):
                     return re.sub(r"^(\.{0,2}\/)*", "", url)
 
+                def simplify(slogan):
+                    return slogan.replace(" ", "-").replace("-", "")
+
                 post_url = post.get("postUrl")
                 logger.debug("post url: %s" % post_url)
                 if not post_url:
@@ -543,10 +542,10 @@ class Tispoon(TispoonBase):
                     raise TispoonError("예상치 못한 오류 발생")
 
                 post_slogan = re.sub(r"^/?entry/", "", post_path)
-                simplified_slogan = remove_prefix(post_slogan.replace("-", ""))
+                simplified_slogan = remove_prefix(simplify(post_slogan))
                 logger.debug("simplified slogan: %s" % simplified_slogan)
 
-                clean_slogan = remove_prefix(slogan)
+                clean_slogan = remove_prefix(simplify(slogan))
                 if simplified_slogan.startswith(quote(u(clean_slogan))):
                     logger.debug("포스팅 발견! -> %s" % u(post.get("title")))
                     return post
@@ -583,7 +582,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -613,7 +612,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -649,7 +648,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -675,7 +674,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -769,7 +768,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -823,14 +822,14 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
                     dotget(res, "tistory.error_message") or "예상치 못한 오류 발생"
                 )
 
-        return dotget(res, "tistory.item.comments.comment")
+        return dotget(res, "tistory.item.comments")
 
     def comment_list(self, post_id):
         """댓글 목록을 가져옵니다."""
@@ -842,7 +841,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -876,7 +875,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -902,7 +901,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -924,7 +923,7 @@ class Tispoon(TispoonBase):
             res = json.loads(r.text)
         except ValueError:
             logger.debug("응답: %s" % r.text)
-            raise
+            raise TispoonError("응답이 JSON 형식이 아닙니다")
         else:
             if r.status_code != 200:
                 raise TispoonError(
@@ -932,364 +931,3 @@ class Tispoon(TispoonBase):
                 )
                 return False
         return True
-
-
-def _info_command(args):
-    """블로그 정보 API를 관리하는 명령어 함수 입니다."""
-    client = Tispoon(args)
-    print("blogs:")
-    for blog in client.blogs:
-        print(
-            textwrap.dedent(
-                """\
-            - name: %s
-              title: %s
-              url: %s"""
-                % (blog.get("name"), blog.get("title"), blog.get("url"))
-            )
-        )
-    if args.post_id:
-        print("posts:")
-        for post_id in args.post_id:
-            post = client.post_read(post_id)
-            # url
-            print("- url: %s" % post.get("postUrl"))
-            # id
-            print("  id: %s" % post.get("id"))
-            # title
-            print("  title: %s" % post.get("title"))
-            # content
-            content = post.get("content")
-            print("  content: |")
-            print("\n".join(map(lambda l: " " * 4 + l, content.split("\n"))))
-            # tags
-            tags = post.get("tags")
-            if tags:
-                print("  tags:")
-                print(
-                    "\n".join(
-                        map(lambda t: " " * 2 + " - " + t, tags.get("tag"))
-                    )
-                )
-
-
-def _post_command(args):
-    """블로그 글을 관리하는 API의 명령어 함수 입니다."""
-    client = Tispoon(args)
-    files = args.file or [] + args.files
-
-    def transform(url):
-        if not args.encode_url:
-            return unquote(url)
-        return url
-
-    if args.list:
-        for post in client.posts:
-            print(
-                textwrap.dedent(
-                    """\
-                    - title: %s
-                      id: %s
-                      url: %s"""
-                    % (
-                        post.get("title"),
-                        post.get("id"),
-                        transform(post.get("postUrl")),
-                    )
-                )
-            )
-        return
-    for file_path in files:
-        client.post_file_path(file_path)
-
-
-def _category_command(args):
-    """카테고리를 관리하는 API의 명령어 함수 입니다."""
-    client = Tispoon(args)
-    categories = client.find_categories(name=args.name, label=args.label)
-    for category in categories:
-        print(
-            textwrap.dedent(
-                """\
-            - name: %s
-              id: %s"""
-                % (category.get("name"), category.get("id"))
-            )
-        )
-
-
-def _comment_command(args):
-    """블로그 댓글을 관리하는 API의 명령어 함수 입니다."""
-    client = Tispoon(args)
-    if args.delete:
-        client.comment_delete(args.post_id, args.comment_id)
-        print("삭제완료: %d" % args.comment_id)
-        return
-
-    if args.list:
-        if args.new:
-            func = client.comment_newest
-        else:
-            func = client.comment_list
-
-        comments = func(args.post_id)
-        for comment in comments:
-            print(
-                textwrap.dedent(
-                    """\
-                - id: %s
-                  name: %s
-                  comment: %s"""
-                    % (
-                        comment.get("id"),
-                        comment.get("name"),
-                        comment.get("comment"),
-                    )
-                )
-            )
-        return
-    if args.content:
-        content = args.content
-    else:
-        content = sys.stdin.read()
-    url = client.comment_write(args.post_id, {"content": content})
-    print("url: %s" % url)
-
-
-def _import_command(args):
-    client = Tispoon(args)
-    if args.blog:
-        blog_name = args.blog
-    else:
-        default_blog = client.default_blog()
-        blog_name = default_blog.get("name")
-    # 옵션이 지정되어 있다면 덮어씁니다.
-    if args.output_dir:
-        blog_name = args.output_dir
-    logger.debug(blog_name)
-    try:
-        os.makedirs(blog_name)
-    except OSError:
-        # Re-raise error if exists file is not directory
-        if not os.path.isdir(blog_name):
-            raise
-        pass
-    for post in client.posts:
-        slogan = client.post_url_to_slogan(post.get("postUrl"))
-        if slogan:
-            identifier = slogan
-        else:
-            identifier = post.get("id")
-        file_name = "%s.md" % identifier
-        dest = os.path.join(blog_name, file_name)
-        if os.path.exists(dest):
-            continue
-        print(post.get("title"), "다운로드 중...")
-
-        post_detail = client.post_read(post.get("id"))
-        attributes = post_detail.keys()
-        except_attr = [
-            "categoryId",
-            "content",
-            "comments",
-            "tags",
-            "trackbacks",
-            "url",
-            "visibility",
-            "slogan",
-            "secondaryUrl",
-            "postUrl",
-        ]
-        content = ""
-        if attributes:
-            content += "---\n"
-            # 자동으로 속성추가
-            for attribute in attributes:
-                if attribute in except_attr:
-                    continue
-                content += "%s: %s\n" % (attribute, post_detail.get(attribute))
-            # 수동으로 속성추가
-            logger.debug("post_detail: %r" % post_detail)
-            visibilities = [
-                VISIBILITY_PRIVATE,
-                VISIBILITY_PROTECTED,
-                VISIBILITY_PUBLISHED,
-            ]
-            visibility = post_detail.get("visibility")
-            for values in visibilities:
-                if int(visibility) in values:
-                    post_visibility = values[0]
-                    break
-            else:
-                post_visibility = int(visibility)
-            content += "visibility: %s\n" % post_visibility
-            tags = post_detail.get("tags")
-            if tags:
-                content += "tag: %s\n" % ", ".join(tags.get("tag"))
-            if slogan:
-                content += "slogan: /%s\n" % slogan
-            content += "---\n\n"
-        content += post_detail.get("content")
-        content += "\n"
-        logger.debug("content: %s" % content)
-        with open(dest, "w") as f:
-            f.write(u(content))
-    print("불러오기가 완료되었습니다!")
-
-
-def main():
-    import argparse  # noqa
-
-    common_parser = argparse.ArgumentParser(add_help=False)
-    common_parser.add_argument("--token", "-t", help="인증 토큰을 설정합니다.")
-    common_parser.add_argument(
-        "--client-id", "-u", help="Open API의 client id값을 설정합니다."
-    )
-    common_parser.add_argument(
-        "--client-secret", "-p", help="Open API의 client secret값을 설정합니다."
-    )
-    common_parser.add_argument(
-        "--blog",
-        "-b",
-        help="블로그 이름을 설정합니다. 예) `xvezda.tistory.com` 의 경우 `xvezda`",
-    )
-    common_parser.add_argument(
-        "--verbose",
-        "-v",
-        action="count",
-        default=0,
-        help="로그의 정보량을 설정합니다. `v`의 갯수에 따라 정보량이 달라집니다.",
-    )
-    common_parser.add_argument(
-        "--version",
-        "-V",
-        action="version",
-        version=__version__,
-        help="버전 정보를 출력하고 종료합니다.",
-    )
-
-    parser = argparse.ArgumentParser(parents=[common_parser])
-    subparsers = parser.add_subparsers(dest="command")
-
-    info_parser = subparsers.add_parser(
-        "info", parents=[common_parser], help="자신의 블로그 정보를 가져오는 API 입니다."
-    )
-    info_parser.add_argument(
-        "--post-id", "-i", action="append", help="정보를 가져올 포스트 아이디를 설정합니다."
-    )
-    info_parser.set_defaults(func=_info_command)
-
-    post_parser = subparsers.add_parser(
-        "post", parents=[common_parser], help="블로그 글을 관리하는 API 입니다."
-    )
-    post_parser.add_argument(
-        "--list", "-l", action="store_true", help="포스트 목록을 가져옵니다."
-    )
-    post_parser.add_argument(
-        "--encode-url",
-        "-e",
-        action="store_true",
-        help="포스트 주소를 URL 인코딩 형태로 보여줍니다.",
-    )
-    # NOTE: Tistory API v1 does not support deleting post.. WHAT?
-    # post_parser.add_argument("--delete", "-d", action="store_true")
-    post_parser.add_argument(
-        "--file",
-        "-f",
-        action="append",
-        help="마크다운 또는 JSON 파일의 경로를 설정합니다. "
-        "`-` 으로 설정하여 stdin으로 부터 읽어올 수 있습니다.",
-    )
-    post_parser.add_argument(
-        "--demo", "-D", action="store_true", help="블로그에 데모 포스팅을 작성합니다.",
-    )
-    post_parser.add_argument("files", nargs="*")
-    post_parser.set_defaults(func=_post_command)
-
-    category_parser = subparsers.add_parser(
-        "category", parents=[common_parser], help="블로그 카테고리를 정보를 가져오는 API 입니다."
-    )
-    category_parser.add_argument(
-        "--name", "-n", action="append", default=[], help="카테고리 이름"
-    )
-    category_parser.add_argument(
-        "--label", "-l", action="append", default=[], help="카테고리 라벨"
-    )
-    category_parser.add_argument(
-        "--id", "-i", action="append", default=[], help="카테고리 아이디"
-    )
-    category_parser.add_argument(
-        "--parent", "-m", action="append", default=[], help="부모 카테고리 아이디"
-    )
-    category_parser.set_defaults(func=_category_command)
-
-    comment_parser = subparsers.add_parser(
-        "comment", parents=[common_parser], help="블로그 댓글을 관리하는 API 입니다."
-    )
-    comment_parser.add_argument(
-        "--list", "-l", action="store_true", help="댓글 목록을 가져옵니다."
-    )
-    comment_parser.add_argument(
-        "--new", "-n", action="store_true", help="최근 댓글 목록을 가져옵니다."
-    )
-    comment_parser.add_argument(
-        "--delete", "-d", action="store_true", help="댓글을 삭제합니다."
-    )
-    comment_parser.add_argument(
-        "--parent-id", "-m", type=str, help="대댓글을 작성할 댓글의 아이디."
-    )
-    comment_parser.add_argument(
-        "--comment-id", "-i", type=str, help="댓글의 아이디."
-    )
-    comment_parser.add_argument(
-        "--post-id", "-A", required=True, type=str, help="댓글을 작성할 포스트의 아이디."
-    )
-    comment_parser.add_argument(
-        "content",
-        nargs="?",
-        type=str,
-        help="댓글의 내용. 설정하지 않으면 stdin으로 부터 읽어옵니다.",
-    )
-    comment_parser.set_defaults(func=_comment_command)
-
-    import_parser = subparsers.add_parser(
-        "import", parents=[common_parser], help="게시된 게시글을 불러오는 명령어입니다."
-    )
-    import_parser.add_argument(
-        "--output-dir",
-        "-O",
-        help="게시글을 저장할 디렉토리를 설정합니다. " "기본값은 블로그의 이름을 사용합니다.",
-    )
-    import_parser.set_defaults(func=_import_command)
-
-    args = parser.parse_args()
-
-    try:
-        # dotenv 모듈이 설치된 경우 `.env` 파일로 작성된 환경변수를 자동으로 읽어옵니다.
-        from dotenv import load_dotenv, find_dotenv  # noqa
-
-        load_dotenv(find_dotenv(usecwd=True), verbose=(args.verbose > 0))
-    except ImportError:
-        pass
-
-    # 로그가 작성되는 단계를 설정합니다.
-    if args.verbose == 1:
-        logger.setLevel(logging.INFO)
-    elif args.verbose == 2:
-        logger.setLevel(logging.DEBUG)
-
-    if not args.command:
-        parser.error("too few arguments")
-
-    try:
-        args.func(args)
-    except Exception as err:
-        if args.verbose > 0:
-            # 오류 발생시 로그의 정보량 단계가 지정된 경우 콜스택 정보를 보여줍니다.
-            print(traceback.format_exc(), file=sys.stderr)
-        parser.error(u(err))
-        parser.print_help()
-
-
-if __name__ == "__main__":
-    main()
